scanpydoc |docs| |travis| |codecov|
===================================

A collection of Sphinx extensions similar to (but more flexible than) numpydoc.

Check the self-documenting documentation at https://icb-scanpydoc.readthedocs-hosted.com

.. |docs| image:: https://readthedocs.com/projects/icb-scanpydoc/badge/?version=latest
   :target: https://icb-scanpydoc.readthedocs-hosted.com/en/latest/?badge=latest
.. |travis| image:: https://travis-ci.com/theislab/scanpydoc.svg?token=nmMvXBaamkdzxsi8X8Rw&branch=master
   :target: https://travis-ci.com/theislab/scanpydoc
.. |codecov| image:: https://codecov.io/gh/theislab/scanpydoc/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/theislab/scanpydoc
